Actions, Resources, and Condition Keys for Amazon GameLift - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon GameLift.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

# Actions, Resources, and Condition Keys for Amazon GameLift

Amazon GameLift (service prefix: `gamelift`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon GameLift
- Resources Defined by Amazon GameLift
- Condition Keys for Amazon GameLift

## Actions Defined by Amazon GameLift

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
AcceptMatch | Registers player acceptance or rejection of a proposed FlexMatch match. | Write |  |  |
CreateAlias | Defines a new alias for a fleet. | Write |  |  |
CreateBuild | Creates a new game build using files stored in an Amazon S3 bucket. | Write |  |  |
CreateFleet | Creates a new fleet of computing resources to run your game servers. | Write |  |  |
CreateGameSession | Starts a new game session on a specified fleet. | Write |  |  |
CreateGameSessionQueue | Sets up a new queue for processing new game session placement requests. | Write |  |  |
CreateMatchmakingConfiguration | Creates a new FlexMatch matchmaker. | Write |  |  |
CreateMatchmakingRuleSet | Creates a new matchmaking rule set for FlexMatch. | Write |  |  |
CreatePlayerSession | Reserves an available game session slot for a player. | Write |  |  |
CreatePlayerSessions | Reserves available game session slots for multiple players. | Write |  |  |
CreateScript | Creates a new Realtime Servers script. | Write |  |  |
CreateVpcPeeringAuthorization | Allows GameLift to create or delete a peering connection between a GameLift fleet VPC and a VPC on another AWS account. | Write |  |  |
CreateVpcPeeringConnection | Establishes a peering connection between your GameLift fleet VPC and a VPC on another account. | Write |  |  |
DeleteAlias | Deletes an alias. | Write |  |  |
DeleteBuild | Deletes a game build. | Write |  |  |
DeleteFleet | Deletes an empty fleet. | Write |  |  |
DeleteGameSessionQueue | Deletes an existing game session queue. | Write |  |  |
DeleteMatchmakingConfiguration | Deletes an existing FlexMatch matchmaker. | Write |  |  |
DeleteMatchmakingRuleSet | Deletes an existing FlexMatch matchmaking rule set. | Write |  |  |
DeleteScalingPolicy | Deletes a set of auto-scaling rules. | Write |  |  |
DeleteScript | Deletes a Realtime Servers script. | Write |  |  |
DeleteVpcPeeringAuthorization | Cancels a VPC peering authorization. | Write |  |  |
DeleteVpcPeeringConnection | Removes a peering connection between VPCs. | Write |  |  |
DescribeAlias | Retrieves properties for an alias. | Read |  |  |
DescribeBuild | Retrieves properties for a game build. | Read |  |  |
DescribeEC2InstanceLimits | Retrieves the maximum allowed and current usage for EC2 instance types. | Read |  |  |
DescribeFleetAttributes | Retrieves general properties, including status, for fleets. | Read |  |  |
DescribeFleetCapacity | Retrieves the current capacity setting for fleets. | Read |  |  |
DescribeFleetEvents | Retrieves entries from a fleet's event log. | Read |  |  |
DescribeFleetPortSettings | Retrieves the inbound connection permissions for a fleet. | Read |  |  |
DescribeFleetUtilization | Retrieves utilization statistics for fleets. | Read |  |  |
DescribeGameSessionDetails | Retrieves properties for game sessions in a fleet, including the protection policy. | Read |  |  |
DescribeGameSessionPlacement | Retrieves details of a game session placement request. | Read |  |  |
DescribeGameSessionQueues | Retrieves properties for game session queues. | Read |  |  |
DescribeGameSessions | Retrieves properties for game sessions in a fleet. | Read |  |  |
DescribeInstances | Retrieves information about instances in a fleet. | Read |  |  |
DescribeMatchmaking | Retrieves details of matchmaking tickets. | Read |  |  |
DescribeMatchmakingConfigurations | Retrieves properties for FlexMatch matchmakers. | Read |  |  |
DescribeMatchmakingRuleSets | Retrieves properties for FlexMatch matchmaking rule sets. | Read |  |  |
DescribePlayerSessions | Retrieves properties for player sessions in a game session. | Read |  |  |
DescribeRuntimeConfiguration | Retrieves the current runtime configuration for a fleet. | Read |  |  |
DescribeScalingPolicies | Retrieves all scaling policies that are applied to a fleet. | Read |  |  |
DescribeScript | Retrieves properties for a Realtime Servers script. | Read |  |  |
DescribeVpcPeeringAuthorizations | Retrieves valid VPC peering authorizations. | Read |  |  |
DescribeVpcPeeringConnections | Retrieves details on active or pending VPC peering connections. | Read |  |  |
GetGameSessionLogUrl | Retrieves the location of stored logs for a game session. | Read |  |  |
GetInstanceAccess | Requests remote access to a specified fleet instance. | Read |  |  |
ListAliases | Retrieves all aliases that are defined in the current region. | List |  |  |
ListBuilds | Retrieves all game build in the current region. | List |  |  |
ListFleets | Retrieves a list of fleet IDs for all fleets in the current region. | List |  |  |
ListScripts | Retrieves properties for all Realtime Servers scripts in the current region. | List |  |  |
PutScalingPolicy | Creates or updates a fleet auto-scaling policy. | Write |  |  |
RequestUploadCredentials | Retrieves fresh upload credentials to use when uploading a new game build. | Read |  |  |
ResolveAlias | Retrieves the fleet ID associated with an alias. | Read |  |  |
SearchGameSessions | Retrieves game sessions that match a set of search criteria. | Read |  |  |
StartFleetActions | Resumes auto-scaling activity on a fleet after it was suspended with StopFleetActions(). | Write |  |  |
StartGameSessionPlacement | Sends a game session placement request to a game session queue. | Write |  |  |
StartMatchBackfill | Requests FlexMatch matchmaking to fill available player slots in an existing game session. | Write |  |  |
StartMatchmaking | Requests FlexMatch matchmaking for one or a group of players and game session placement for a resulting match. | Write |  |  |
StopFleetActions | Suspends auto-scaling activity on a fleet. | Write |  |  |
StopGameSessionPlacement | Cancels a game session placement request that is in progress. | Write |  |  |
StopMatchmaking | Cancels a matchmaking or match backfill request that is in progress. | Write |  |  |
UpdateAlias | Updates the properties of an existing alias. | Write |  |  |
UpdateBuild | Updates an existing build's metadata. | Write |  |  |
UpdateFleetAttributes | Updates the general properties of an existing fleet. | Write |  |  |
UpdateFleetCapacity | Adjusts a fleet's capacity settings. | Write |  |  |
UpdateFleetPortSettings | Adjusts a fleet's port settings. | Write |  |  |
UpdateGameSession | Updates the properties of an existing game session. | Write |  |  |
UpdateGameSessionQueue | Updates properties of an existing game session queue. | Write |  |  |
UpdateMatchmakingConfiguration | Updates properties of an existing FlexMatch matchmaking configuration. | Write |  |  |
UpdateRuntimeConfiguration | Updates how server processes are configured on instances in an existing fleet. | Write |  |  |
UpdateScript | Updates the metadata and content of an existing Realtime Servers script. | Write |  |  |
ValidateMatchmakingRuleSet | Validates the syntax of a FlexMatch matchmaking rule set. | Read |  |  |

## Resources Defined by Amazon GameLift

Amazon GameLift does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to Amazon GameLift, specify `“Resource”: “*”` in your policy.

## Condition Keys for Amazon GameLift

GameLift has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available Keys for Conditions in the IAM Policy Reference.

On this page:

- Actions Defined by Amazon GameLift
- Resources Defined by Amazon GameLift
- Condition Keys for Amazon GameLift

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more